=======================================
Flask-Obscure API
=======================================

.. automodule:: flask_obscure

Flask Integration
=======================================

.. autoclass:: flask_obscure.Obscure
    :members: __init__, init_app
    :inherited-members:

Converters
=======================================

.. autoclass:: flask_obscure.Num
    :members:

.. autoclass:: flask_obscure.Hex

.. autoclass:: flask_obscure.Base32

.. autoclass:: flask_obscure.Base64

.. autoclass:: flask_obscure.Tame

